@@ -23,17 +23,15 @@
 import logging
 import pprint
 
-
-from o7util.table import TableParam, ColumnParam, Table
-import o7util.menu as o7m
-import o7util.input as o7i
-import o7util.terminal as o7t
 import o7util.format as o7f
-
-from o7cli.base import Base
+import o7util.input as o7i
+import o7util.menu as o7m
+import o7util.terminal as o7t
+from o7util.table import ColumnParam, Table, TableParam
 
 import o7cli.logstream
 import o7cli.s3
+from o7cli.base import Base
 
 logger = logging.getLogger(__name__)
 
@@ -309,7 +307,7 @@ class CodeBuild(Base):
     # *************************************************
     #
     # *************************************************
-    def display_build_detailsa(self):
+    def display_build_details(self):
         """Displays the details of a builds"""
 
         self.refresh_build_details()
@@ -366,6 +364,15 @@ class CodeBuild(Base):
         )
         Table(export_params, self.build.get("exportedEnvironmentVariables", [])).print()
 
+    # *************************************************
+    #
+    # *************************************************
+    def menu_build_details_exec_id(self, exec_id):
+        """Menu to view details of a build"""
+
+        self.builds = [{"id": exec_id}]
+        self.menu_build_details(1)
+
     # *************************************************
     #
     # *************************************************
@@ -413,7 +420,7 @@ class CodeBuild(Base):
         #         callback=self.view_artifacts
         #     )
         # )
-        obj.display_callback = self.display_build_detailsa
+        obj.display_callback = self.display_build_details
         obj.loop()
 
     # *************************************************
