@@ -24,14 +24,13 @@ import logging
 import pprint
 
 import botocore
-
-from o7util.table import TableParam, ColumnParam, Table
-import o7util.menu as o7m
 import o7util.input as o7i
+import o7util.menu as o7m
 import o7util.terminal as o7t
+from o7util.table import ColumnParam, Table, TableParam
 
-from o7cli.base import Base
 import o7cli.codebuild
+from o7cli.base import Base
 
 logger = logging.getLogger(__name__)
 
@@ -88,7 +87,6 @@ class CodePipeline(Base):
         # Reformat some data
         # and get details
         for pipeline in self.pipelines:
-
             # Get status of the last Excution
             last_exec = self.get_executions(pipeline["name"], max_exec=1)
             pipeline["execStart"] = last_exec[0].get("startTime", "NA")
@@ -117,13 +115,11 @@ class CodePipeline(Base):
 
         # Merge Stage & Action State
         for stage in resp_pl["pipeline"]["stages"]:
-
             # print(f'processing stage {stage["name"]}')
             stage["status"] = "na"
 
             for stage_state in resp_state["stageStates"]:
                 if stage_state["stageName"] == stage["name"]:
-
                     # FOUND Stage
                     # print(f'  fOUND stage state->'); pprint.pprint(stage_state)
 
@@ -141,7 +137,6 @@ class CodePipeline(Base):
                     )
 
                     for action in stage["actions"]:
-
                         # print(f'  processing action {action["name"]}')
                         action["status"] = "na"
                         action["id"] = action_id
@@ -149,7 +144,6 @@ class CodePipeline(Base):
 
                         for action_state in stage_state["actionStates"]:
                             if action_state["actionName"] == action["name"]:
-
                                 # Found Action
                                 action["latestExecution"] = action_state.get(
                                     "latestExecution", {}
@@ -202,7 +196,6 @@ class CodePipeline(Base):
 
         # # Merge Actions with summary
         for action in reversed(resp_actions["actionExecutionDetails"]):
-
             logger.info(f'{action_id}. {action["stageName"]=} {action["actionName"]=}')
 
             action["id"] = action_id
@@ -233,7 +226,6 @@ class CodePipeline(Base):
 
         # Reformat some data
         for summary in summaries:
-
             summary["sourceSummary"] = "No Source"
             source_revisions = summary.get("sourceRevisions", [])
             if len(source_revisions) >= 1:
@@ -409,7 +401,6 @@ class CodePipeline(Base):
         )
 
         for stage in stages:
-
             # Check if Inbound Allowed
             if "inboundTransitionState" in stage:
                 allowed = stage["inboundTransitionState"].get("enabled", True)
@@ -505,7 +496,7 @@ class CodePipeline(Base):
 
             namespace = action.get("input", {}).get("namespace", "")
 
-            action_output = action.get("output", {}).get("output_variables", {})
+            action_output = action.get("output", {}).get("outputVariables", {})
             for output_key in action_output.keys():
                 output_variables.append(
                     {
@@ -616,7 +607,6 @@ class CodePipeline(Base):
             and status == "InProgress"
             and action_cat == "Approval"
         ):
-
             key = o7i.input_string("Option -> Approve(a) Reject(r) Back (any other) :")
             if key != "a" and key != "r":
                 return
@@ -642,7 +632,6 @@ class CodePipeline(Base):
             )
 
         if status == "Failed":
-
             exec_id = "TBD"
 
             if action_provider == "CodeBuild":
@@ -655,16 +644,27 @@ class CodePipeline(Base):
                     pl_name=self.pipeline_name, stage_name=stage_name, exec_id=exec_id
                 )
             elif key == "d":
-                o7cli.codebuild.CodeBuild(session=self.session).MenuBuildDetail(
-                    external_execution_id
-                )
+                o7cli.codebuild.CodeBuild(
+                    session=self.session
+                ).menu_build_details_exec_id(exec_id=external_execution_id)
 
         elif action_provider == "CodeBuild":
             key = o7i.input_string("Option -> Details(d) Back (any) :")
             if key == "d":
-                o7cli.codebuild.CodeBuild(session=self.session).MenuBuildDetail(
-                    external_execution_id
-                )
+                o7cli.codebuild.CodeBuild(
+                    session=self.session
+                ).menu_build_details_exec_id(exec_id=external_execution_id)
+
+    # *************************************************
+    #
+    # *************************************************
+    def print_execution_details_raw(self, index):
+        """Print raw details of an action in an execution"""
+        if not 0 < index <= len(self.execution["actions"]):
+            return
+
+        pprint.pprint(self.execution["actions"][index - 1])
+        o7i.wait_input()
 
     # *************************************************
     #
@@ -694,11 +694,7 @@ class CodePipeline(Base):
             o7m.Option(
                 key="int",
                 short="Raw Action",
-                callback=lambda x: pprint.pprint(
-                    self.execution["actions"][x - 1]
-                    if 0 < x <= len(self.execution["actions"])
-                    else None
-                ),
+                callback=self.print_execution_details_raw,
             )
         )
         obj.display_callback = self.display_execution_details
@@ -786,7 +782,6 @@ def menu(**kwargs):
 #
 # *************************************************
 if __name__ == "__main__":
-
     logging.basicConfig(
         level=logging.INFO, format="[%(levelname)-5.5s] [%(name)s] %(message)s"
     )
