@@ -20,39 +20,35 @@
 # --------------------------------
 #
 # --------------------------------
-import os
-import logging
 import datetime
-import time
-import warnings
+import logging
+import os
 import pprint
+import time
 from decimal import Decimal
 
-import pandas as pd
-
 import boto3
 import botocore.errorfactory
-from botocore.exceptions import ClientError
-
-from o7util.table import TableParam, ColumnParam, Table
+import o7util.html_report as o7hr
+import o7util.input as o7i
 import o7util.menu as o7m
 import o7util.terminal as o7t
-import o7util.input as o7i
-import o7util.html_report as o7hr
+import pandas as pd
+from botocore.exceptions import ClientError
+from o7util.table import ColumnParam, Table, TableParam
 
 try:
     import o7pdf.report_security_hub_standard as o7rshs
-except ImportError as exept:
+except ImportError:
     # warnings.warn(f'Error importing o7pdf.report_security_hub_standard: {exept}')
     _has_o7pdf = False
 else:
     _has_o7pdf = True
 
 
-from o7cli.base import Base
-
-import o7cli.sts
 import o7cli.organizations as o7org
+import o7cli.sts
+from o7cli.base import Base
 
 logger = logging.getLogger(__name__)
 
@@ -691,7 +687,7 @@ class SecurityHub(Base):
             & (df["Suppression_Reason"] != "")
         ]
 
-        for index, row in df.iterrows():
+        for index, row in df.iterrows():  # noqa: B007
             print(
                 f"Suppressing {row['ControlId']} - {row['ResName']} - {row['Suppression_Reason']}"
             )
@@ -715,7 +711,7 @@ class SecurityHub(Base):
             & (df["Suppression_Reason"] != df["WorkflowNote"])
         ]
 
-        for index, row in df.iterrows():
+        for _index, row in df.iterrows():
             print(
                 f"Correctinf {row['ControlId']} - {row['ResName']} - {row['Suppression_Reason']}"
             )
@@ -754,7 +750,6 @@ class SecurityHub(Base):
             # df_global = self.df_standards_global.loc[standards] if self.df_standards_global is not None else None
         except KeyError:
             df_results = None
-            df_global = None
 
         if df_results is not None:
 
@@ -1018,7 +1013,7 @@ class SecurityHub(Base):
         table_html = Table(params, df_results.to_dict(orient="records")).generate_html()
         print("")
 
-        report.add_section(title=f"Standards Results", html=table_html)
+        report.add_section(title="Standards Results", html=table_html)
 
         return report.generate()
 
@@ -1050,7 +1045,7 @@ class SecurityHub(Base):
 
         ret = []
 
-        for index, standard in self.df_standards.iterrows():
+        for index, standard in self.df_standards.iterrows():  # noqa: B007
 
             if standard["StandardsStatus"] != "READY":
                 continue
@@ -1219,7 +1214,7 @@ class SecurityHub(Base):
         standards = self.df_standards[
             self.df_standards["StandardsStatus"] == "READY"
         ].copy()
-        for index, row in standards.iterrows():
+        for _index, row in standards.iterrows():
             std_short = row["Short"]
             params.columns.append(
                 ColumnParam(
@@ -1425,9 +1420,7 @@ class SecurityHub(Base):
         """Save to Excel"""
 
         filename = f"aws-securityhub-{datetime.datetime.now().isoformat()[0:19].replace(':','-')}.xlsx"
-        with pd.ExcelWriter(
-            filename
-        ) as writer:  # pylint: disable=abstract-class-instantiated
+        with pd.ExcelWriter(filename) as writer:
 
             df_parameters = pd.DataFrame(
                 [
@@ -1484,7 +1477,7 @@ class SecurityHub(Base):
         """Save HTML report"""
 
         filename = f"aws-securityhub-report-{datetime.datetime.now().isoformat()[0:19].replace(':','-')}.html"
-        filename = f"aws-securityhub-report-test.html"
+        filename = "aws-securityhub-report-test.html"
         report = self.generate_html_report()
 
         try:
@@ -1644,7 +1637,7 @@ class SecurityHub(Base):
         standards = self.df_standards[
             self.df_standards["StandardsStatus"] == "READY"
         ].copy()
-        for index, row in standards.iterrows():
+        for _index, row in standards.iterrows():
             std_short = row["Short"]
             params.columns.append(
                 ColumnParam(
@@ -1769,7 +1762,7 @@ class SecurityHub(Base):
                 section_params, other_findings[0:10].to_dict(orient="records")
             ).print()
             print("")
-            report.add_section(title=f"Other Findings", html=section_html)
+            report.add_section(title="Other Findings", html=section_html)
 
         return report.generate()
 
@@ -1800,7 +1793,7 @@ class SecurityHub(Base):
                 "low": account["Low"],
             }
 
-            for index, row in self.df_standards[
+            for _index, row in self.df_standards[
                 self.df_standards["StandardsStatus"] == "READY"
             ].iterrows():
                 std_short = row["Short"]
@@ -1829,7 +1822,7 @@ class SecurityHub(Base):
             self.load_accounts()
 
         items = []
-        for account_id, account in self.df_accounts.iterrows():
+        for account_id, _account in self.df_accounts.iterrows():
             print(f"Reading history for account: {account_id}")
             repsonse = table.query(
                 KeyConditionExpression=(
